package org.ow2.bonita.facade.exception;

import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.util.BonitaException;
/**
 * Thrown by the ManagementAPI if a failure during the deployment operation occured.
 * @author Marc Blachon, Guillaume Porcher, Charles Souillard, Miguel Valdes, Pierre Vigneras
 */
public class DeploymentException extends BonitaException {

  private final String className;
  private final PackageDefinitionUUID packageUUID;

  /**
   * Constructs an DeploymentException with the specified detail message.
   * ClassName and packageDefinitionUUID are set to null.
   * @param msg the detail message.
   */
  public DeploymentException(String msg) {
    super(msg);
    this.className = null;
    this.packageUUID = null;
  }

  /**
   * Constructs a DeploymentException with the specified detail message and the throwable cause.
   * ClassName and packageDefinitionUUID are set to null.
   * @param msg the detail message.
   * @param cause exception causing the abort.
   */
  public DeploymentException(String msg, Throwable cause) {
    super(msg, cause);
    this.className = null;
    this.packageUUID = null;
  }

  /**
   * Constructs a DeploymentException with the specified detail message and className parameter.
   * PackageId is set to null.
   * @param msg the detail message.
   * @param className the name of the class to deploy.
   */
  public DeploymentException(String msg, String className) {
    super(msg + className);
    this.className = className;
    this.packageUUID = null;
  }

  /**
   * Constructs a DeploymentException with the specified detail message and className, packageDefinitionUUID parameters.
   * @param msg the detail message.
   * @param className the name of the class to deploy.
   * @param packageUUID the UUID of the package.
   */
  public DeploymentException(String msg, String className, PackageDefinitionUUID packageUUID) {
    super(msg + " className: " + className + " packageDefinitionUUID: " + packageUUID);
    this.className = className;
    this.packageUUID = packageUUID;
  }

  public String getClassName() {
    return this.className;
  }

  public PackageDefinitionUUID getPackageDefinitionUUID() {
    return this.packageUUID;
  }

}
