/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.exception;

import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.util.BonitaException;

/**
 * Thrown by methods of ManagementAPI or QueryDefinitionAPI if the recorded runtime information
 * of the package has not been found.
 * @author Marc Blachon, Guillaume Porcher, Charles Souillard, Miguel Valdes, Pierre Vigneras
 *
 */
public class PackageNotFoundException extends BonitaException {

  private final String packageId;
  private final String version;

  private final PackageDefinitionUUID packageUUID;

  public PackageNotFoundException(final String packageId) {
    super("Can't find a package with id " + packageId);
    this.packageId = packageId;
    this.packageUUID = null;
    this.version = null;
  }

  public PackageNotFoundException(final String packageId, final String version) {
    super("Can't find a package with id " + packageId);
    this.packageId = packageId;
    this.version = version;
    this.packageUUID = null;
  }

  public PackageNotFoundException(final PackageDefinitionUUID packageUUID) {
    super("Can't find a package with uuid " + packageUUID);
    this.packageUUID = packageUUID;
    this.packageId = null;
    this.version = null;
  }

  public PackageNotFoundException(PackageNotFoundException e) {
    super(e.getMessage());
    this.packageId = e.getPackageId();
    this.packageUUID = e.getPackageUUID();
    this.version = null;
  }

  public static PackageNotFoundException build(Throwable e) {
    if (!(e instanceof PackageNotFoundException)) {
      throw new BonitaInternalException("Cannot create a ProcessNotFoundException", e);
    }
    return new PackageNotFoundException((PackageNotFoundException)e);
  }
  public String getPackageId() {
    return this.packageId;
  }

  public String getVersion() {
    return version;
  }

  public PackageDefinitionUUID getPackageUUID() {
    return packageUUID;
  }
}
