package org.ow2.bonita.facade.internal;

import java.net.URL;
import java.rmi.RemoteException;
import java.util.Collection;
import java.util.Map;

import org.ow2.bonita.facade.def.element.BusinessArchive;
import org.ow2.bonita.facade.def.majorElement.ProcessDefinition;
import org.ow2.bonita.facade.exception.DeploymentException;
import org.ow2.bonita.facade.exception.PackageNotFoundException;
import org.ow2.bonita.facade.exception.UndeletableInstanceException;
import org.ow2.bonita.facade.exception.UndeletablePackageException;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;

/**
 * For internal use only.
 */
public interface InternalManagementAPI {

  Map<String, ProcessDefinition> deploy(final BusinessArchive businessARchive) throws DeploymentException, RemoteException;

  Map<String, ProcessDefinition> deployBar(final URL barFileURL) throws DeploymentException, RemoteException;

  Map<String, ProcessDefinition> deployBar(final byte[] barFile) throws DeploymentException, RemoteException;

  void deployClass(byte[] clazz) throws DeploymentException, RemoteException;

  void deployClasses(Collection<byte[]> classes) throws DeploymentException, RemoteException;

  void  deployClassesInJar(byte[] classesArchive) throws DeploymentException, RemoteException;

  void undeploy(final PackageDefinitionUUID packageUUID) throws DeploymentException, RemoteException;

  void removeClass(String className) throws DeploymentException, RemoteException;

  void removeClasses(String[] classNames) throws DeploymentException, RemoteException;

  void replaceClass(String className, byte[] newClazz) throws DeploymentException, RemoteException;

  void clearHistory() throws RemoteException;

  Map<String, ProcessDefinition> deployXpdl(final URL xpdlURL) throws DeploymentException, RemoteException;
  Map<String, ProcessDefinition> deployXpdl(final byte[] xpdlFile) throws DeploymentException, RemoteException;

  Map<String, ProcessDefinition> deploy(final URL xpdlURL,
      final Class< ? >[] classes) throws DeploymentException, RemoteException;

  Map<String, ProcessDefinition> deployZip(final URL zipURL) throws DeploymentException, RemoteException;
  Map<String, ProcessDefinition> deployZip(final byte[] zipFile) throws DeploymentException, RemoteException;

  void deletePackage(PackageDefinitionUUID pacDefinitionUUID) throws PackageNotFoundException,
  UndeletablePackageException, UndeletableInstanceException, RemoteException;
}
