package org.ow2.bonita.facade.internal;

import java.rmi.RemoteException;
import java.util.Set;

import org.ow2.bonita.facade.def.majorElement.ActivityDefinition;
import org.ow2.bonita.facade.def.majorElement.DataFieldDefinition;
import org.ow2.bonita.facade.def.majorElement.PackageDefinition;
import org.ow2.bonita.facade.def.majorElement.ParticipantDefinition;
import org.ow2.bonita.facade.def.majorElement.ProcessDefinition;
import org.ow2.bonita.facade.exception.ActivityDefNotFoundException;
import org.ow2.bonita.facade.exception.ActivityNotFoundException;
import org.ow2.bonita.facade.exception.DataFieldNotFoundException;
import org.ow2.bonita.facade.exception.PackageNotFoundException;
import org.ow2.bonita.facade.exception.ParticipantNotFoundException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.uuid.ActivityDefinitionUUID;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.facade.uuid.ParticipantDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;

/**
 * For internal use only.
 */
public interface InternalQueryDefinitionAPI {

  PackageDefinition getPackage(String packageId, String version, 
      String queryList) throws PackageNotFoundException, RemoteException;

  ProcessDefinition getProcess(String packageId, String processId, String processVersion, String queryList)
    throws ProcessNotFoundException, RemoteException;
  
  Set<ProcessDefinition> getProcesses(String processId, String processVersion, String queryList) throws RemoteException;
  
  Set<PackageDefinition> getPackages(String queryList) throws RemoteException;
  
  Set<PackageDefinition> getPackages(String packageId, String queryList) throws RemoteException;
  
  PackageDefinition getPackage(PackageDefinitionUUID packageDefinitionUUID, 
      String queryList) throws RemoteException, PackageNotFoundException;
  
  Set<PackageDefinition> getPackages(PackageDefinition.PackageState state, String queryList) throws RemoteException;
  
  Set<PackageDefinition> getPackages(String packageId, PackageDefinition.PackageState state, String queryList) 
    throws RemoteException, PackageNotFoundException;
  
  Set<ProcessDefinition> getPackageProcesses(PackageDefinitionUUID packageDefinitionUUID, String queryList) 
    throws RemoteException, PackageNotFoundException;
  
  ProcessDefinition getPackageProcess(PackageDefinitionUUID packageDefinitionUUID, String processId, String queryList) 
    throws RemoteException, PackageNotFoundException, ProcessNotFoundException;
  
  Set<ProcessDefinition> getProcesses(String queryList) throws RemoteException;
  
  Set<ProcessDefinition> getProcesses(String processId, String queryList) throws RemoteException;
  Set<ProcessDefinition> getPackageProcesses(String packageId, String processId, String queryList) throws RemoteException;
  
  ProcessDefinition getProcess(ProcessDefinitionUUID processDefinitionUUID, 
      String queryList) throws RemoteException, ProcessNotFoundException;
  
  Set<ProcessDefinition> getProcesses(ProcessDefinition.ProcessState processState, String queryList) throws RemoteException;
  
  Set<ProcessDefinition> getProcesses(String processId, ProcessDefinition.ProcessState processState, String queryList) 
    throws RemoteException;
  
  Set<ParticipantDefinition> getProcessParticipants(ProcessDefinitionUUID processDefinitionUUID, String queryList) 
    throws RemoteException, ProcessNotFoundException;
  
  ParticipantDefinition getProcessParticipant(ProcessDefinitionUUID processDefinitionUUID,
      String participantId, String queryList) throws RemoteException, ProcessNotFoundException, ParticipantNotFoundException;

  Set<ActivityDefinition> getProcessActivities(ProcessDefinitionUUID processDefinitionUUID, String queryList) 
    throws RemoteException, ProcessNotFoundException;
  
  ActivityDefinition getProcessActivity(ProcessDefinitionUUID processDefinitionUUID, String activityId, String queryList) 
    throws RemoteException, ProcessNotFoundException, ActivityNotFoundException;
  
  ActivityDefinitionUUID getProcessActivityId(ProcessDefinitionUUID processDefinitionUUID,
      String activityName, String queryList) throws RemoteException, ProcessNotFoundException;

  ParticipantDefinitionUUID getProcessParticipantId(ProcessDefinitionUUID processDefinitionUUID,
      String participantName, String queryList) throws RemoteException, ProcessNotFoundException;
  
  PackageDefinition getLastPackage(String packageId, String queryList) throws RemoteException, PackageNotFoundException;
  
  ProcessDefinition getLastProcess(String packageId, String processId, 
      String queryList) throws RemoteException, ProcessNotFoundException;

  Set<DataFieldDefinition> getProcessDataFields(ProcessDefinitionUUID processDefinitionUUID, String queryList)
    throws RemoteException, ProcessNotFoundException;

  DataFieldDefinition getProcessDataField(ProcessDefinitionUUID processDefinitionUUID, String dataFieldId, String queryList)
    throws RemoteException, ProcessNotFoundException, DataFieldNotFoundException;

  Set<DataFieldDefinition> getActivityDataFields(ActivityDefinitionUUID uuid, String queryList)
    throws RemoteException, ActivityDefNotFoundException;
  
  DataFieldDefinition getActivityDataField(ActivityDefinitionUUID activityDefinitionUUID, String dataFieldId, String queryList)
    throws RemoteException, ActivityDefNotFoundException, DataFieldNotFoundException;
}
