package org.ow2.bonita.facade.internal;

import java.rmi.RemoteException;
import java.util.Collection;
import java.util.Map;
import java.util.Set;

import org.ow2.bonita.facade.exception.ActivityNotFoundException;
import org.ow2.bonita.facade.exception.InstanceNotFoundException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.exception.TaskNotFoundException;
import org.ow2.bonita.facade.exception.VariableNotFoundException;
import org.ow2.bonita.facade.runtime.ActivityBody;
import org.ow2.bonita.facade.runtime.ActivityInstance;
import org.ow2.bonita.facade.runtime.ProcessInstance;
import org.ow2.bonita.facade.runtime.TaskInstance;
import org.ow2.bonita.facade.runtime.TaskState;
import org.ow2.bonita.facade.uuid.ActivityInstanceUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;
import org.ow2.bonita.facade.uuid.TaskUUID;

/**
 * For internal use only.
 */
public interface InternalQueryRuntimeAPI {

  ProcessInstance getProcessInstance(ProcessInstanceUUID instanceUUID, 
      String queryList) throws InstanceNotFoundException, RemoteException;

  Set<ProcessInstance> getProcessInstances(String queryList) throws RemoteException;

  Set<ProcessInstance> getProcessInstances(ProcessDefinitionUUID processUUID, 
      String queryList) throws ProcessNotFoundException, RemoteException;

  ActivityInstance<ActivityBody> getActivityInstance(ActivityInstanceUUID
      activityUUID, String queryList) throws ActivityNotFoundException, RemoteException;

  Set<ActivityInstance<ActivityBody>> getActivityInstances(
      ProcessInstanceUUID instanceUUID, String queryList) throws InstanceNotFoundException, RemoteException;

  Set<ActivityInstance<ActivityBody>> getActivityInstances(ProcessInstanceUUID instanceUUID,
      String activityId, String queryList) throws InstanceNotFoundException, ActivityNotFoundException, RemoteException;

  ActivityInstance<TaskInstance> getTask(TaskUUID taskUUID, String queryList) throws TaskNotFoundException, RemoteException;

  Set<ActivityInstance<TaskInstance>> getTasks(
      ProcessInstanceUUID instanceUUID, String queryList) throws InstanceNotFoundException, RemoteException;

  Collection<ActivityInstance<TaskInstance>> getTaskList(ProcessInstanceUUID instanceUUID, TaskState taskState, String queryList)
    throws InstanceNotFoundException, RemoteException;

  Collection<ActivityInstance<TaskInstance>> getTaskList(TaskState taskState, String queryList) throws RemoteException;

  Object getActivityInstanceVariable(ActivityInstanceUUID activityUUID,
      String variableId, String queryList) throws ActivityNotFoundException, VariableNotFoundException, RemoteException;

  Map<String, Object> getActivityInstanceVariables(ActivityInstanceUUID
      activityUUID, String queryList)throws ActivityNotFoundException, RemoteException;

  Object getProcessInstanceVariable(ProcessInstanceUUID instanceUUID,
      String variableId, String queryList) throws InstanceNotFoundException, VariableNotFoundException, RemoteException;

  Map<String, Object> getProcessInstanceVariables(ProcessInstanceUUID
      instanceUUID, String queryList) throws InstanceNotFoundException, RemoteException;

  Object getVariable(ActivityInstanceUUID activityUUID,
      String variableId, String queryList) throws ActivityNotFoundException, VariableNotFoundException, RemoteException;
  Map<String, Object> getVariables(ActivityInstanceUUID activityUUID, String queryList)
    throws InstanceNotFoundException, ActivityNotFoundException, RemoteException;
  Collection<ActivityInstance<TaskInstance>> getTaskList(ProcessInstanceUUID instanceUUID, 
      String userId, TaskState taskState, String queryList)
    throws InstanceNotFoundException, RemoteException;
  Collection<ActivityInstance<TaskInstance>> getTaskList(String userId, 
      TaskState taskState, String queryList) throws RemoteException;

}
